# Generated by Django 4.2.3 on 2023-07-31 06:09

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ReadHistory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(choices=[('altnight', 'あるとな'), ('furi', 'ふり')], max_length=255, verbose_name='名前')),
                ('category', models.CharField(choices=[('tech', '技術書'), ('business', 'ビジネス書')], max_length=255, verbose_name='カテゴリ')),
                ('title', models.CharField(max_length=255, verbose_name='書籍名')),
                ('price', models.IntegerField(verbose_name='価格')),
                ('read_at', models.DateField(verbose_name='読了日')),
                ('is_public', models.BooleanField(verbose_name='公開するかどうか')),
                ('is_favorite', models.BooleanField(blank=True, null=True, verbose_name='評価')),
            ],
            options={
                'db_table': 'read_history',
            },
        ),
    ]



from django.db import models


class ReadHistory(models.Model):
    name = models.CharField("名前", max_length=255, choices=(
        ("altnight", "あるとな"),
        ("furi", "ふり")
    ))
    category = models.CharField("カテゴリ", max_length=255, choices=(
        ("tech", "技術書"),
        ("business", "ビジネス書"),
    ))
    title = models.CharField("書籍名", max_length=255)
    price = models.IntegerField("価格")
    read_at = models.DateField("読了日")
    is_public = models.BooleanField("公開するかどうか")
    is_favorite = models.BooleanField("評価", blank=True, null=True)

    class Meta:
        db_table = "read_history"



import json

from django.shortcuts import render
from django.http import JsonResponse
from django.views.decorators.csrf import csrf_exempt

from app.models import ReadHistory


def index(request):
    context = {}
    return render(request, "app/index.html", context)


@csrf_exempt
def insert_log(request):
    d = json.loads(request.body)
    ReadHistory.objects.create(
        name=d["name"],
        category=d["category"],
        title=d["title"],
        price=d["price"],
        read_at=d["readAt"],
        is_public=d["isPublic"],
        is_favorite=d["isFavorite"],
    )
    return JsonResponse({})


def read_log(request):
    qs = ReadHistory.objects.filter(is_public=True).order_by("-id")
    d = [{
        "id": obj.id,
        "name": obj.name,
        "category": obj.category,
        "title": obj.title,
        "price": obj.price,
        "readAt": obj.read_at.strftime("%Y-%m-%d"),
        "isFavorite": obj.is_favorite,
    } for obj in qs]
    return JsonResponse({"result": d})
